#ifndef _SHADE_H
#define _SHADE_H
#include "matrix.h"

/**** Structures and types ********
 ****stolen and modified from poly.h *******/

typedef struct {		/* A POLYGON VERTEX */
    double sx, sy, sz, sw;	/* screen space position (sometimes homo.) */
    double x, y, z;		/* world space position */
    vector normal;
    double r, g, b;		/* (red,green,blue) color */
} Poly_vert;

typedef struct{
  int v[3];          /* vertices */
  unsigned long mask;     /* interpolation mask for vertex elems */
  int n;                    /* number of sides */
  vector normal;          /* normal (used for back face culling) */
  int degenerate;         /* 2 or more of vertices are the same */
}Triangle;

typedef struct {		/* WINDOW: A DISCRETE 2-D RECTANGLE */
    int x0, y0;			/* xmin and ymin */
    int x1, y1;			/* xmax and ymax (inclusive) */
} Window;

typedef struct{     /* For Z-buffer hidden surface determination */  
  double y;
  int vertex;
}Y_struct;

/**** Defines *********************/

#define MAXLINE 80
#define NORTH 2     /* z coordinate */
#define UP 1   /* y coordinate */
#define EAST 0    /* x coordinate */

#define ASCII 0
#define BINARY 1


/****** Function Prototypes *******/
#ifdef ANSI
void Read_binary_polygon_data(char *DataFileName,
			      int *Num_Vertices, double ***Vertices,
			      int *Num_Polygons, int ***Polygons);
void Read_ascii_polygon_data(char *DataFileName,
			     int *Num_Vertices, double ***Vertices,
			     int *Num_Polygons, int ***Polygons);
void Read_binary_color(char *DataFileName,
		       int *Num_Vertices, double ***Vertices);
void Read_ascii_color(char *DataFileName,
		      int *Num_Vertices, double ***Vertices);

extern void myerror(int errorno);
pixelproc(int x, int z, Poly_vert* pnt);
#else
void Read_binary_polygon_data();
void Read_ascii_polygon_data();
void Read_binary_color();
void Read_ascii_color();
extern void myerror();
extern pixelproc();
#endif /* ANSI */

void poly_scan();
#endif














